package Weed::Components::Core::ChildNode;

use Weed '
X3DChildNode : X3DNode { 
	SFNode [in,out] metadata NULL [X3DMetadataObject]
}
';

1;
__END__
